#!/bin/sh

OUTPUT=$1
BINDIR=$2
CONFDIR=$3
SYSCONFDIR=$4

rm -f $OUTPUT

echo "[Unit]" >> $OUTPUT
echo "Description=Read Route Record 1.18-1" >> $OUTPUT

echo >> $OUTPUT

echo "[Service]" >> $OUTPUT
echo "ExecStart=${BINDIR}/rrr -s -e ${SYSCONFDIR}/rrr.conf ${CONFDIR}/" >> $OUTPUT
echo "KillSignal=SIGTERM" >> $OUTPUT
echo "User=rrr" >> $OUTPUT
echo "Group=rrr" >> $OUTPUT

echo >> $OUTPUT

echo "[Install]" >> $OUTPUT
echo "WantedBy=multi-user.target" >> $OUTPUT
